==> iohub-sdk-client-1.0-20250507.025055-82-sources.jar: com/ovopark/iohub/sdk/client/Client2WorkTransport.java <==
package com.ovopark.iohub.sdk.client;

import com.ovopark.iohub.sdk.model.*;
import com.ovopark.iohub.sdk.model.instream.*;
import com.ovopark.iohub.sdk.model.outstream.*;
import com.ovopark.iohub.sdk.model.test.ExportRenderResponse;
import com.ovopark.iohub.sdk.model.test.ExportStartResponse;
import com.ovopark.iohub.sdk.model.test.ReplyRenderResponse;
import com.ovopark.module.shared.Session;

public interface Client2WorkTransport {


    ClientNodeTaskRegisterResponse exportHeartbeat(ClientNodeTaskRegisterRequest clientNodeTaskRegisterRequest);

    TaskLogResponse log(TaskLogRequest taskLogRequest);

    ExportPushStartResponse start(ExportPushStartRequest exportPushStartRequest);

    CreateExportRecordResponse createExportRecord(CreateExportRecordRequest createExportRecordRequest);

    ExportPushDataResponse push(ExportPushDataRequest exportPushDataRequest);

    ExportPushCommitResponse commit(ExportPushCommitRequest exportPushCommitRequest);

    ClientNodeTaskRegisterResponse importHeartbeat(ClientNodeTaskRegisterRequest clientNodeTaskRegisterRequest);

    ImportReplyResponse importReply(ImportReplyRequest importReplyRequest);

    ImportCommitResponse importCommit(ImportCommitRequest importCommitRequest);

    ImportPushDataRequest parseOnlyForTest(String file, String uri);

    ReplyRenderResponse renderReplyOnlyForTest(ImportReplyRequest importReplyRequest);

    ExportStartResponse startOnlyForTest(String uri);

    ExportRenderResponse renderOnlyForTest(ExportPushCommitRequest exportPushCommitRequest);

    ExportPushDataResponse pushOnlyForTest(ExportPushDataRequest exportPushDataRequest);

    Session parseSessionOnlyForTest(String token);


    ExportPushDataResponse pushRenderJob(ExportPushDataRequest exportPushDataRequest);

    ExportPushCommitResponse commitRenderJob(ExportPushCommitRequest exportPushCommitRequest);

    RenderJobHeartbeatResponse heartbeatRenderJob(RenderJobHeartbeatRequest renderJobHeartbeatRequest);

}

==> iohub-sdk-client-1.0-20250508.091149-84-sources.jar: com/ovopark/iohub/sdk/client/Client2WorkTransport.java <==
package com.ovopark.iohub.sdk.client;

import com.ovopark.iohub.sdk.model.*;
import com.ovopark.iohub.sdk.model.instream.*;
import com.ovopark.iohub.sdk.model.outstream.*;
import com.ovopark.iohub.sdk.model.test.ExportRenderResponse;
import com.ovopark.iohub.sdk.model.test.ExportStartResponse;
import com.ovopark.iohub.sdk.model.test.ReplyRenderResponse;
import com.ovopark.module.shared.Session;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.multipart.MultipartFile;

public interface Client2WorkTransport {


    ClientNodeTaskRegisterResponse exportHeartbeat(ClientNodeTaskRegisterRequest clientNodeTaskRegisterRequest);

    TaskLogResponse log(TaskLogRequest taskLogRequest);

    ExportPushStartResponse start(ExportPushStartRequest exportPushStartRequest);

    CreateExportRecordResponse createExportRecord(CreateExportRecordRequest createExportRecordRequest);

    ExportPushDataResponse push(ExportPushDataRequest exportPushDataRequest);

    ExportPushCommitResponse commit(ExportPushCommitRequest exportPushCommitRequest);

    ClientNodeTaskRegisterResponse importHeartbeat(ClientNodeTaskRegisterRequest clientNodeTaskRegisterRequest);

    ImportReplyResponse importReply(ImportReplyRequest importReplyRequest);

    ImportCommitResponse importCommit(ImportCommitRequest importCommitRequest);

    ImportPushDataRequest parseOnlyForTest(String file, String uri);

    ReplyRenderResponse renderReplyOnlyForTest(ImportReplyRequest importReplyRequest);

    ExportStartResponse startOnlyForTest(String uri);

    ExportRenderResponse renderOnlyForTest(ExportPushCommitRequest exportPushCommitRequest);

    ExportPushDataResponse pushOnlyForTest(ExportPushDataRequest exportPushDataRequest);

    Session parseSessionOnlyForTest(String token);


    ExportPushDataResponse pushRenderJob(ExportPushDataRequest exportPushDataRequest);

    ExportPushCommitResponse commitRenderJob(ExportPushCommitRequest exportPushCommitRequest);

    RenderJobHeartbeatResponse heartbeatRenderJob(RenderJobHeartbeatRequest renderJobHeartbeatRequest);

    ReadJobParseResponse parseReadJob(String file,ReadJobParseRequest readJobParseRequest);

    ReadJobHeartbeatResponse heartbeatReadJob(ReadJobHeartbeatRequest readJobHeartbeatRequest);

}
